@@ -21,6 +21,7 @@ from .models.cbamresnet import *
 from .models.resattnet import *
 from .models.sknet import *
 from .models.scnet import *
+from .models.regnet import *
 from .models.diaresnet import *
 from .models.diapreresnet import *
 from .models.pyramidnet import *
@@ -115,6 +116,7 @@ from .models.fcn8sd import *
 from .models.pspnet import *
 from .models.deeplabv3 import *
 from .models.icnet import *
+from .models.fastscnn import *
 from .models.sinet import *
 from .models.bisenet import *
 from .models.danet import *
@@ -142,8 +144,7 @@ from .models.superpointnet import *
 # from .models.others.oth_sinet import *
 # from .models.others.oth_ibppose import *
 # from .models.others.oth_bisenet1 import *
-from .models.others.oth_regnet import *
-from .models.regnet import *
+# from .models.others.oth_regnet import *
 
 __all__ = ['get_model']
 
@@ -336,6 +337,32 @@ _models = {
     'scneta50': scneta50,
     'scneta101': scneta101,
 
+    'regnetx002': regnetx002,
+    'regnetx004': regnetx004,
+    'regnetx006': regnetx006,
+    'regnetx008': regnetx008,
+    'regnetx016': regnetx016,
+    'regnetx032': regnetx032,
+    'regnetx040': regnetx040,
+    'regnetx064': regnetx064,
+    'regnetx080': regnetx080,
+    'regnetx120': regnetx120,
+    'regnetx160': regnetx160,
+    'regnetx320': regnetx320,
+
+    'regnety002': regnety002,
+    'regnety004': regnety004,
+    'regnety006': regnety006,
+    'regnety008': regnety008,
+    'regnety016': regnety016,
+    'regnety032': regnety032,
+    'regnety040': regnety040,
+    'regnety064': regnety064,
+    'regnety080': regnety080,
+    'regnety120': regnety120,
+    'regnety160': regnety160,
+    'regnety320': regnety320,
+
     'diaresnet10': diaresnet10,
     'diaresnet12': diaresnet12,
     'diaresnet14': diaresnet14,
@@ -1018,6 +1045,8 @@ _models = {
 
     'icnet_resnetd50b_cityscapes': icnet_resnetd50b_cityscapes,
 
+    'fastscnn_cityscapes': fastscnn_cityscapes,
+
     'sinet_cityscapes': sinet_cityscapes,
 
     'bisenet_resnet18_celebamaskhq': bisenet_resnet18_celebamaskhq,
@@ -1081,58 +1110,6 @@ _models = {
     # 'oth_ibppose': oth_ibppose,
 
     # 'oth_bisenet': oth_bisenet,
-
-    'regnetx_002': regnetx_002,
-    'regnetx_004': regnetx_004,
-    'regnetx_006': regnetx_006,
-    'regnetx_008': regnetx_008,
-    'regnetx_016': regnetx_016,
-    'regnetx_032': regnetx_032,
-    'regnetx_040': regnetx_040,
-    'regnetx_064': regnetx_064,
-    'regnetx_080': regnetx_080,
-    'regnetx_120': regnetx_120,
-    'regnetx_160': regnetx_160,
-    'regnetx_320': regnetx_320,
-
-    'regnety_002': regnety_002,
-    'regnety_004': regnety_004,
-    'regnety_006': regnety_006,
-    'regnety_008': regnety_008,
-    'regnety_016': regnety_016,
-    'regnety_032': regnety_032,
-    'regnety_040': regnety_040,
-    'regnety_064': regnety_064,
-    'regnety_080': regnety_080,
-    'regnety_120': regnety_120,
-    'regnety_160': regnety_160,
-    'regnety_320': regnety_320,
-
-    'regnetx002': regnetx002,
-    'regnetx004': regnetx004,
-    'regnetx006': regnetx006,
-    'regnetx008': regnetx008,
-    'regnetx016': regnetx016,
-    'regnetx032': regnetx032,
-    'regnetx040': regnetx040,
-    'regnetx064': regnetx064,
-    'regnetx080': regnetx080,
-    'regnetx120': regnetx120,
-    'regnetx160': regnetx160,
-    'regnetx320': regnetx320,
-
-    'regnety002': regnety002,
-    'regnety004': regnety004,
-    'regnety006': regnety006,
-    'regnety008': regnety008,
-    'regnety016': regnety016,
-    'regnety032': regnety032,
-    'regnety040': regnety040,
-    'regnety064': regnety064,
-    'regnety080': regnety080,
-    'regnety120': regnety120,
-    'regnety160': regnety160,
-    'regnety320': regnety320,
 }
 
 
