@@ -1,5 +1,5 @@
 """
-    ESPNetv2, implemented in PyTorch.
+    ESPNetv2 for ImageNet-1K, implemented in PyTorch.
     Original paper: 'ESPNetv2: A Light-weight, Power Efficient, and General Purpose Convolutional Neural Network,'
     https://arxiv.org/abs/1811.11431.
 """
@@ -57,8 +57,7 @@ class ShortcutBlock(nn.Module):
         self.conv2 = conv1x1_block(
             in_channels=in_channels,
             out_channels=out_channels,
-            activation=None,
-            activate=False)
+            activation=None)
 
     def forward(self, x):
         x = self.conv1(x)
@@ -138,10 +137,10 @@ class ESPBlock(nn.Module):
             in_channels=out_channels,
             out_channels=out_channels,
             groups=num_branches,
-            activation=None,
-            activate=False)
+            activation=None)
         self.preactiv = PreActivation(in_channels=out_channels)
-        self.activ = nn.PReLU(out_channels)
+        if not self.downsample:
+            self.activ = nn.PReLU(out_channels)
 
     def forward(self, x, x0):
         y = self.reduce_conv(x)
@@ -369,7 +368,7 @@ class ESPNetv2(nn.Module):
 def get_espnetv2(width_scale,
                  model_name=None,
                  pretrained=False,
-                 root=os.path.join('~', '.torch', 'models'),
+                 root=os.path.join("~", ".torch", "models"),
                  **kwargs):
     """
     Create ESPNetv2 model with specific parameters.
@@ -509,7 +508,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -529,13 +527,18 @@ def _test():
         net.eval()
         weight_count = _calc_width(net)
         print("m={}, {}".format(model.__name__, weight_count))
-        assert (model != espnetv2_wd2 or weight_count == 1241332)
-        assert (model != espnetv2_w1 or weight_count == 1670072)
-        assert (model != espnetv2_w5d4 or weight_count == 1965440)
-        assert (model != espnetv2_w3d2 or weight_count == 2314856)
-        assert (model != espnetv2_w2 or weight_count == 3498136)
+        # assert (model != espnetv2_wd2 or weight_count == 1241332)
+        # assert (model != espnetv2_w1 or weight_count == 1670072)
+        # assert (model != espnetv2_w5d4 or weight_count == 1965440)
+        # assert (model != espnetv2_w3d2 or weight_count == 2314856)
+        # assert (model != espnetv2_w2 or weight_count == 3498136)
+        assert (model != espnetv2_wd2 or weight_count == 1241092)
+        assert (model != espnetv2_w1 or weight_count == 1669592)
+        assert (model != espnetv2_w5d4 or weight_count == 1964832)
+        assert (model != espnetv2_w3d2 or weight_count == 2314120)
+        assert (model != espnetv2_w2 or weight_count == 3497144)
 
-        x = Variable(torch.randn(1, 3, 224, 224))
+        x = torch.randn(1, 3, 224, 224)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
